#!/usr/bin/env python

import sys
import os.path as path
sys.path.append(path.realpath(__file__ + '/../../'))

from threading import Thread, Lock
import time
from logtop import logtop  # use make python-module to build it


def build_lines():
    while True:
        for i in range(10):
            yield str(i % 3)
            time.sleep(1)
        time.sleep(10)


class LogtopPrinter(Thread):
    def __init__(self):
        self.lock = Lock()
        self.logtop = logtop(10000)
        Thread.__init__(self)
        self.daemon = True

    def run(self):
        while True:
            self.lock.acquire()
            data = self.logtop.get(6)
            count = self.logtop.qte_of_elements()
            timespan = self.logtop.timespan()
            self.lock.release()
            if timespan == 0:
                timespan = 1
            print "%.2f l/s (%d lines, %.2f seconds): %s" % (count / timespan,
                                                             count,
                                                             timespan,
                                                             repr(data))
            time.sleep(1)

    def feed(self, line):
        self.lock.acquire()
        self.logtop.feed(line)
        self.lock.release()


printer = LogtopPrinter()
printer.start()

for line in build_lines():
    printer.feed(line)



#!/usr/bin/env python3

import pprint
import sys
from logtop import logtop


"""
This example show a complete usage of the python API,
It can be used like this:

$ make python-module
$ python3 -m venv logtop_venv
$ . logtop_venv/bin/activate
$ python3 -m pip install .
$
$ cat /etc/passwd | cut -d: -f7 | python3 examples/example1.py

"""

l = logtop(10000)
for line in sys.stdin:
    l.feed(line)

pprint.pprint(l.get(10))



#!/usr/bin/env python

"""
setup.py file for logtop
"""

from distutils.core import setup, Extension


logtop_module = Extension('_logtop',
                          sources=['logtop_wrap.c',
                                   'src/logtop.c',
                                   'src/avl.c',
                                   'src/history.c',
                                   'src/libavl/avl.c'])

setup(name='logtop',
      version='0.2',
      author="Julien Palard",
      author_email="julien@palard.fr",
      description="""Live line frequency analyzer""",
      long_description="""logtop is a System Administrator tool analyzing line
       rate on stdin. It reads on stdin and print a constantly updated result
       displaying, in columns: Line number, count, frequency,
       and the actual line.""",
      keywords=['log', 'top', 'lines', 'analyzer', 'nginx', 'apache',
                'varnish', 'tail'],
      url='https://github.com/JulienPalard/logtop',
      classifiers=['Development Status :: 5 - Production/Stable',
                   'Intended Audience :: System Administrators',
                   'License :: OSI Approved :: BSD License'],
      ext_modules=[logtop_module],
      py_modules=["logtop"])
